import React, {useState} from 'react';
import {StyleSheet, View, TextInput, Text, ScrollView} from 'react-native';
import {onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {Dropdown} from 'react-native-material-dropdown';
import SharePreference from '../../common/SharePreference';
// import _ from 'lodash';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch, isFinish} = props;
  const configurations = JSON.parse(item.configurations);
  const dataCorrect = configurations.data[0];
  const dataQuestion = configurations.paragraph_sections[0];
  const dataSelect = configurations.correct_answer[0];
  // dataSelect.sort();

  const dataSelectNew = [];
  const dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = {value: i, answer: ''};
    dataSelectNew.push(newItem);
    dataAnswer.push('');
  });

  const [data, setData] = useState(dataAnswer);

  const setDataAnswer = (answer, index) => {
    data[index] = answer;
    onConfigurations(item, data, dispatch);
  };

  // console.log(43, item);

  const replaceText = (item) => {
    const replace1 = item.replace('*', '').replace('\n', '');
    // const replaceA = _.replace(replace1, new RegExp(' A:', 'g'), '\nA:');
    // const replaceB = _.replace(replaceA, new RegExp(' B:', 'g'), '\nB:');
    return replace1;
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView contentContainerStyle={styles.containerScroll}>
        {dataQuestion.map((item, index) => {
          // console.log(51, item);
          return (
            <View style={styles.containerQues} key={index}>
              <Text style={styles.txtContent}>{replaceText(item)}</Text>
              {item.includes('*') ? (
                <TextInput
                  editable={isFinish ? false : true}
                  underlineColorAndroid="transparent"
                  style={styles.textInput}
                  returnKeyType="done"
                  autoCapitalize="none"
                  onChangeText={(text) => setDataAnswer(text, index)}
                />
              ) : (
                item.includes('(') && (
                  <View style={{flexDirection: 'row', alignItems: 'center'}}>
                    <View style={styles.viewDropdown}>
                      <Dropdown
                        disabled={isFinish}
                        style={{alignItems: 'center'}}
                        containerStyle={styles.contentStyle}
                        inputContainerStyle={{
                          borderBottomWidth: 0,
                        }}
                        labelHeight={0}
                        data={dataSelectNew}
                        rippleOpacity={0}
                        baseColor="orange"
                        renderAccessory={() => null}
                        onChangeText={(value) => setDataAnswer(value, index)}
                        renderBase={({value}) => {
                          return (
                            <Text style={styles.text}>
                              <Text>{value}</Text>
                            </Text>
                          );
                        }}
                      />
                    </View>
                  </View>
                )
              )}
            </View>
          );
        })}
      </ScrollView>
      {isFinish && (
        <Text style={[styles.txtAnswer, {marginTop: 100, marginBottom: 10}]}>
          Đáp án
        </Text>
      )}
      {isFinish && (
        <ScrollView>
          {dataSelect.map((answer, index) => {
            return (
              <Text style={[styles.txtAnswer]} key={index}>
                {`(${index + 1}) ` + answer}
              </Text>
            );
          })}
        </ScrollView>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flexWrap: 'wrap',
    // width: '100%',
    // minHeight: 200,
    marginEnd: 20,
    alignItems: 'center',
  },
  containerScroll: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  containerQues: {
    flexDirection: 'row',
    marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 16,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 12,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
    // backgroundColor: '#D7E9FF',
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
  text: {
    textAlign: 'center',
    color: 'black',
    fontSize: 16,
    marginTop: 2,
  },
  txtContent: {
    fontSize: 16,
    lineHeight: 24,
  },
  txtAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 4,
    lineHeight: 28,
  },
});
