import React, {useEffect} from 'react';
import {
  TouchableOpacity,
  StyleSheet,
  View,
  Text,
  SafeAreaView,
  Image,
  Linking,
  Platform,
  ActivityIndicator,
  Alert,
  ScrollView,
  useWindowDimensions,
} from 'react-native';
import moment from 'moment';
import {useDispatch, useSelector} from 'react-redux';
import SharePreference from '../../common/SharePreference';
import * as actions from '../../redux/actions';
import {createSelector} from 'reselect';
import AntDesign from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import RNExitApp from 'react-native-exit-app';
import HTMLView from 'react-native-htmlview';
// import HTML from 'react-native-render-html';

AntDesign.loadFont();
FontAwesome.loadFont();
const getData = createSelector(
  (state) => state.reducersAccepted,
  (reducersAccepted) => reducersAccepted,
);
export default (props) => {
  const {navigation, route} = props;
  const dispatch = useDispatch();
  const {data, loading, error} = useSelector(getData);

  const fixLinkTest =
    // 'https://test-dev.ekidpro.com/main/test/joined/37229/take?code=OBX8ALK6NX';
    'https://test-dev.ekidpro.com/main/test/free/19/take?code=IO3JZODR33';

  useEffect(() => {
    if (route.params?.linkUrl) {
      getInfoFromUrl(route.params.linkUrl);
    } else {
      if (Platform.OS === 'android') {
        const NativeLinking = require('react-native/Libraries/Linking/NativeLinking')
          .default;
        NativeLinking.getInitialURL().then((url) => {
          getInfoFromUrl(fixLinkTest);
        });
      } else {
        Linking.getInitialURL().then((url) => {
          getInfoFromUrl(fixLinkTest);
        });
      }
    }
  }, []);

  const getInfoFromUrl = (linkQA) => {
    if (linkQA && linkQA.includes('code=')) {
      const arrSplit = linkQA.split('code=');
      if (arrSplit.length > 0) {
        const code = arrSplit[1];
        let domain = 'test.ekidpro.com';
        const arrSplit2 = linkQA.split('/');
        if (arrSplit2.length > 3) {
          domain = arrSplit2[2];
        }
        const auth = {
          device_id: '',
          domain: domain,
          code: code,
        };
        const param = {
          auth: auth,
          // test_id: 36771,
          test_id: arrSplit2[6],
        };
        dispatch({type: actions.REQUEST_AUTHENCATION, payload: param});
      }
    }
  };

  // console.log(95, error);
  if (data == null && !error) {
    return (
      <View style={styles.container}>
        <ActivityIndicator size="large" color="#7d9db5" />
      </View>
    );
  }

  if (error) {
    return (
      <>
        {Alert.alert('', error, [
          {
            text: 'Thoát',
            onPress: () => {
              route.params?.nav
                ? route.params.nav.goBack()
                : RNExitApp.exitApp();
            },
          },
        ])}
      </>
    );
  }

  return (
    <SafeAreaView style={styles.safe}>
      <ScrollView>
        <View style={styles.flexView}>
          <Image
            style={styles.logo}
            source={require('../../assets/images/logo.png')}
          />
          <FontAwesome
            name="question-circle-o"
            style={{fontSize: 30, marginRight: 20, color: 'gray'}}
          />
        </View>
        <View style={styles.content}>
          <View style={styles.viewShadow}>
            <View style={styles.viewRadius}>
              <Text
                style={{fontSize: 70, fontWeight: 'bold', color: '#0abb87'}}>
                E
              </Text>
            </View>
          </View>
          <View style={styles.body}>
            <Text style={styles.title}>{data.title}</Text>
            <HTMLView value={data.outline} style={{marginHorizontal: 40}} />
            {/* <HTML
              source={{html: data.test_data.outline}}
              ignoredStyles={['font-family']}
            /> */}
          </View>

          <View style={styles.viewUser}>
            <Text style={styles.hintName}>Học sinh: </Text>
            <Text style={styles.name}>{data.examinee_name}</Text>
          </View>
          <View style={styles.quizView}>
            <View
              style={{
                flexDirection: 'row',
                alignItems: 'center',
              }}>
              <View style={{width: 100}}>
                <Text style={styles.subHeader}>{data.total_questions}</Text>
                <Text style={styles.subHeader}>câu hỏi</Text>
              </View>
            </View>
            <View style={styles.viewTime}>
              <Text style={styles.time}>{data.time_limit}p</Text>
              <Text style={styles.time}>thời gian làm bài</Text>
            </View>
          </View>
          <TouchableOpacity
            style={styles.button}
            onPress={() => {
              dispatch({
                type: actions.REQUEST_IS_FINISH,
                payload: {isFinish: false},
              });
              SharePreference.startTest = moment().unix();
              navigation.replace('Start');
            }}>
            <Text style={styles.textButton}>Bắt đầu</Text>
          </TouchableOpacity>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  safe: {
    flex: 1,
    backgroundColor: '#fff',
  },
  content: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
  },

  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },

  viewShadow: {
    alignItems: 'center',
    justifyContent: 'center',
    width: 200,
    height: 200,
    borderRadius: 100,
    backgroundColor: '#fff',
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.23,
    shadowRadius: 2.62,
    elevation: 4,
  },
  viewRadius: {
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#fff6e9',
    width: 185,
    height: 185,
    borderRadius: 95,
    borderWidth: 1,
    borderStyle: 'dashed',
    borderColor: '#f9ce76',
  },
  body: {
    alignItems: 'center',
  },
  title: {
    marginVertical: '5%',
    fontSize: 20,
    marginHorizontal: 20,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  outline: {
    paddingHorizontal: 16,
    textAlign: 'center',
    fontSize: 14,
  },
  name: {
    fontSize: 18,
    color: '#3b4056',
    fontWeight: 'bold',
  },
  hintName: {
    fontSize: 16,
    color: 'gray',
    fontWeight: 'bold',
  },
  viewUser: {
    marginTop: 20,
    height: 55,
    width: 330,
    borderWidth: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    paddingLeft: 15,
    borderRadius: 15,
    borderColor: '#bfbfbf',
  },
  flexView: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  subHeader: {
    marginHorizontal: 5,
    fontSize: 16,
    fontWeight: '500',
    color: '#fff',
    textAlign: 'center',
  },
  logo: {
    width: '30%',
    resizeMode: 'contain',
    marginLeft: 20,
  },
  quizView: {
    marginTop: 20,
    borderRadius: 15,
    width: 330,
    height: 55,
    backgroundColor: '#8993bb',
    paddingHorizontal: 20,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  viewTime: {
    backgroundColor: '#fff',
    width: 180,
    height: 45,
    borderRadius: 15,
    justifyContent: 'center',
    padding: 10,
  },
  time: {
    fontSize: 16,
    fontWeight: '500',
    color: '#8993bb',
    textAlign: 'center',
  },
  button: {
    marginTop: 30,
    backgroundColor: '#2196f3',
    width: 130,
    height: 50,
    borderRadius: 25,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textButton: {
    color: '#fff',
    fontSize: 18,
    fontWeight: 'bold',
  },
});
