import superagent from 'superagent';
import {store} from '../index';

export const request = ({
  method = 'get',
  url,
  body = null,
  headers = {},
  query = {},
}) => {
  let promise = null;

  let customHeaders = headers;
  const state = store.getState();
  switch (method) {
    case 'get':
      promise = superagent.get(url);
      break;

    case 'post':
      if (url.includes('api/uploads')) {
        promise = superagent
          .post(url)
          .attach('file', {uri: body.record.fsPath, name: body.player._path})
          .field('folder', 'answer');
      } else {
        promise = superagent.post(url).send(body);
      }
      break;

    case 'put':
      promise = superagent.put(url).send(body);
      break;

    case 'delete':
      promise = superagent.delete(url);
      break;

    default:
      return Promise.resolve();
  }

  return promise
    .query(query)
    .set(customHeaders)
    .timeout({response: 30000})
    .then((response) => {
      const {body} = response;
      const {code, message} = body;
      console.log('request', body);
      if (code === 401) {
        throw new Error(message || 'Invalid access token');
      }
      return response;
    });
};
